@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -17,9 +20,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-dynamodbstreams-lambda",
-    "2.53.0",
+    "2.54.1",
     __name__[0:-6],
-    "aws-dynamodbstreams-lambda@2.53.0.jsii.tgz",
+    "aws-dynamodbstreams-lambda@2.54.1.jsii.tgz",
 )
 
 __all__ = [
